@@ -1,3 +1,4 @@
+#' @rdname print.effectsize_table
 #' @export
 plot.effectsize_table <- function(x, ...) {
   if (!requireNamespace("see", quietly = TRUE)) {
@@ -13,6 +14,3 @@ plot.equivalence_test_effectsize <- function(x, ...) {
   }
   NextMethod()
 }
-
-#' @export
-plot.effectsize_difference <- plot.effectsize_table
