@@ -334,7 +334,7 @@ if (require("testthat") && require("effectsize")) {
   })
 
 
-# Include intercept -------------------------------------------------------
+  # Include intercept -------------------------------------------------------
 
 
 
@@ -377,8 +377,9 @@ if (require("testthat") && require("effectsize")) {
 
     suppressWarnings(suppressMessages(
       a <- afex::aov_car(value ~ treatment * gender + Error(id),
-                         include_aov = TRUE,
-                         data = obk.long)
+        include_aov = TRUE,
+        data = obk.long
+      )
     ))
 
     resE0 <- eta_squared(a)
@@ -399,4 +400,41 @@ if (require("testthat") && require("effectsize")) {
     expect_equal(resE1[[2]][1], resA1[[5]][1], tolerance = 0.01)
   })
 
+
+  # tidymodels --------------------------------------------------------------
+  test_that("ets_squared | tidymodels", {
+    skip_on_cran()
+    skip_if_not_installed("tidymodels")
+    require("tidymodels", quietly = TRUE)
+
+    set.seed(123)
+    mod_lm <-
+      linear_reg() %>%
+      set_engine("lm") %>%
+      set_mode("regression") %>%
+      fit(mpg ~ am + vs, data = mtcars)
+
+    set.seed(123)
+    df_lm <- as.data.frame(eta_squared(mod_lm, ci = 0.95))
+
+    expect_equal(
+      df_lm,
+      structure(
+        list(
+          Parameter = c("am", "vs"),
+          Eta2_partial = c(0.534050980382337, 0.509657899929074),
+          CI = c(0.95, 0.95),
+          CI_low = c(0.270477566572333, 0.242410781810851),
+          CI_high = c(0.698019260414593, 0.681154789342689)
+        ),
+        class = "data.frame",
+        row.names = 1:2,
+        partial = TRUE,
+        generalized = FALSE,
+        ci = 0.95,
+        ci_method = list(method = "ncp", distribution = "t")
+      ),
+      tolerance = 0.001
+    )
+  })
 }
